@@ -13,3 +13,8 @@ del registerTestSetup
 
 from zope.i18nmessageid import MessageFactory
 InterventionGettext = MessageFactory("schooltool.intervention")
+
+import schooltool.common
+
+schooltool.common.register_lauchpad_project(__package__, 'schooltool.intervention')
+
