@@ -34,6 +34,7 @@ from zope.publisher.browser import BrowserView
 from zope.schema import Bool, Date
 from zope.security.checker import canWrite
 from zope.security.proxy import removeSecurityProxy
+from zope.security import checkPermission
 from zope.traversing.api import getParents
 from zope.traversing.browser.absoluteurl import absoluteURL
 from zope.i18n import translate
@@ -55,7 +56,8 @@ from schooltool.contact.interfaces import IContact
 from schooltool.course.interfaces import ISection, IInstructor
 from schooltool.email.interfaces import IEmailUtility, IEmailContainer
 from schooltool.email.mail import status_messages
-from schooltool.intervention import intervention, sendmail, catalog
+from schooltool.intervention.catalog import getStudentFirstName, getStudentLastName
+from schooltool.intervention import intervention, sendmail
 from schooltool.intervention import interfaces
 from schooltool.person.interfaces import IPerson
 from schooltool.relationship import getRelatedObjects
@@ -208,13 +210,13 @@ class InterventionTableFormatter(IndexedTableFormatter):
             index='first_name',
             name='first_name',
             title=_(u'First Name'),
-            getter=lambda i, f: catalog.getStudentFirstName(i),
+            getter=lambda i, f: getStudentFirstName(i),
             subsort=True)
         last_name = IndexedLocaleAwareGetterColumn(
             index='last_name',
             name='last_name',
             title=_(u'Last Name'),
-            getter=lambda i, f: catalog.getStudentLastName(i),
+            getter=lambda i, f: getStudentLastName(i),
             subsort=True)
         inter_type = GetterColumn(
             name='intervention_type',
@@ -661,6 +663,10 @@ class FlourishInterventionStudentView(EmailMixin, flourish.page.Page):
                 })
         return goals
 
+    @property
+    def canModify(self):
+        return checkPermission('schooltool.edit', self.context)
+
     def learnerOf(self):
         """Get the sections the student is a member of."""
         results = []
@@ -758,10 +764,7 @@ class InterventionStudentTertiaryNavigationManager(ViewletManager):
     def items(self):
         result = []
         schoolyears = ISchoolYearContainer(ISchoolToolApplication(None))
-        active = schoolyears.getActiveSchoolYear()
-        if 'schoolyear' in self.request:
-            schoolyear_id = self.request['schoolyear']
-            active = schoolyears.get(schoolyear_id, active)
+        active = ISchoolYear(removeSecurityProxy(self.context).__parent__)
         for schoolyear in schoolyears.values():
             url = '%s?schoolyear=%s' % (
                 absoluteURL(self.context, self.request),
@@ -1561,7 +1564,7 @@ class FlourishInterventionGoalView(flourish.page.Page):
 
     @property
     def canModify(self):
-        return True
+        return canWrite(self.context, 'goal')
 
     @property
     def done(self):
@@ -1637,13 +1640,10 @@ class FlourishInterventionGoalsView(flourish.page.Page):
                 'goal_met': v.goal_met and _('Yes') or _('No'),
                 'persons_responsible': ', '.join(intervention.contactsName(
                     v.persons_responsible)),
+                'canModify': canWrite(v, 'goal')
             })
         return goals
 
-    @property
-    def canModify(self):
-        return True
-
     @property
     def done(self):
         if 'nexturl' in self.request:
